@@ -57,9 +57,14 @@ class MessagePrinter:
         width = self.term_width
         return f"{'=' * ((width - 2 - len(self._label(msg))) // 2 + 1)} {self._label(msg)} {'=' * ((width - 2 - len(self._label(msg))) // 2 - (1 if len(self._label(msg)) % 2 == 0 else 0))}"
 
+    def _route(self, msg: Message) -> str:
+        width = self.term_width
+        return f"{'-' * ((width - 2 - len(msg.routing_key)) // 2 + 1)} {msg.routing_key} {'-' * ((width - 2 - len(msg.routing_key)) // 2 - (1 if len(msg.routing_key) % 2 == 0 else 0))}"
+
     @typechecked
     def watch(self, msg: Message) -> None:
         print(colored(self._header(msg), self._priority_color(msg)))
+        print(colored(self._route(msg), self._priority_color(msg)))
         print(colored(pformat(msg.contents), self._priority_color(msg)))
         print(colored('=' * self.term_width, self._priority_color(msg)))
         if self.num_msgs is not None:  # pragma: no cover
